@@ -49,7 +49,7 @@ class RosTrail(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosTrailProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosTrailProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -293,7 +293,7 @@ class RosTrailLogging(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosTrailLoggingProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosTrailLoggingProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
@@ -665,7 +665,7 @@ class Trail(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["TrailProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[TrailProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -712,7 +712,7 @@ class TrailLogging(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["TrailLoggingProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[TrailLoggingProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
